/* ver.B.b16.03(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"ppm2r64",
	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
	"ver.B.b16.03(BLAZE)",
	2007,6,26,
	0,
	"ppm to r64/cr format converter ",
};

